version 8.0
log using bargain_diagnostic.log, replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:  bargain_diagnostic.do                                 *;
*     Date:       March 30, 2005                                        *;
*     Author:     SNG                                                   *;
*     Purpose:    Show that Weibull is correct parametric specification *;
*     Data Used:  coalition.dta                                         *;
*     Output File:    bargain_diagnostic.log                            *;
*     Machine:    laptop (compaq)                                       *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set more off;

use C:\datasets\coalition.dta;

gen pec_parties = pec * govtparties;
gen minority = 0;
replace minority=1 if majority2==0;
gen invest_minority = investiture*minority;

stset bargain2;


*     ****************************************************************  *;
*           Try parametric models.                                      *;
*     ****************************************************************  *;

streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(exp) time;

predict double cs, csnell;
stset cs;
sts generate km=s;
gen double H = -log(km);
sort cs;
graph7 H cs cs, c(ll) s(..) xlab ylab b2 
    (Exponential) t1(H(t) based on Cox-Snell Residuals) 
    saving(coxsnellexp, replace);
drop H cs km;

stset bargain2;

streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(weib) nohr;

predict double cs, csnell;
stset cs;
sts generate km=s;
gen double H = -log(km);
sort cs;
graph7 H cs cs, c(ll) s(..) xlab ylab b2 
    (Weibull) t1(H(t) based on Cox-Snell Residuals) 
    saving(coxsnellweib, replace);
drop H cs km;

stset bargain2;

streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(loglog);

predict double cs, csnell;
stset cs;
sts generate km=s;
gen double H = -log(km);
sort cs;
graph7 H cs cs, c(ll) s(..) xlab ylab b2 
    (Log Logistic) t1(H(t) based on Cox-Snell Residuals) 
    saving(coxsnellll, replace);
drop H cs km;

stset bargain2;

streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(lognorm) time;

predict double cs, csnell;
stset cs;
sts generate km=s;
gen double H = -log(km);
sort cs;
graph7 H cs cs, c(ll) s(..) xlab ylab b2 
    (Log Normal) t1(H(t) based on Cox-Snell Residuals) 
    saving(coxsnellln, replace);
drop H cs km;

stset bargain2;

streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(gompertz) nohr;

predict double cs, csnell;
stset cs;
sts generate km=s;
gen double H = -log(km);
sort cs;
graph7 H cs cs, c(ll) s(..) xlab ylab b2 
    (Gompertz) t1(H(t) based on Cox-Snell Residuals) 
    saving(coxsnellgomp, replace);
drop H cs km;

stset bargain2;

streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(gamma) time;

predict double cs, csnell;
stset cs;
sts generate km=s;
gen double H = -log(km);
sort cs;
graph7 H cs cs, c(ll) s(..) xlab ylab b2 
    (Generalized Gamma) t1(H(t) based on Cox-Snell Residuals) 
    saving(coxsnellgam, replace);
drop H cs km;



gr7 using, saving(null, replace);
gr7 using coxsnellexp coxsnellweib null 
    coxsnellll coxsnellln null coxsnellgomp coxsnellgam null, 
    saving(coxsnellparm, replace);
translate @Graph c:\data\coxsnellparm.wmf, replace;

stset bargain2;

streg investiture minority invest_minority govtparties pec pec_parties range previnoffice if postelection==1, dist(gamma) time;
  
*     ****************************************************************  *;
*               If kappa=0, then the log-normal is implied.             *;
*     ****************************************************************  *;

test [kappa]_b[_cons] = 0;

*     ****************************************************************  *;
*               If kappa=1, then the Weibull is implied.                *;
*     ****************************************************************  *;

test [kappa]_b[_cons] = 1;

*     ****************************************************************  *;
*           If kappa=sigma=1, then the exponential is implied.          *;
*     ****************************************************************  *;

test [kappa]_b[_cons] = 1, notest;
test [ln_sig]_b[_cons] = 0, accum;

*     ****************************************************************  *;
*               If sigma=1, then the gamma is implied.                  *;
*     ****************************************************************  *;

test [ln_sig]_b[_cons] = 0;











log close;
exit;
