version 8.0
log using data_setup.log, replace
#delimit ;

*     ***************************************************************** *;
*     ***************************************************************** *;
*     File-Name:data_setup.do                                           *;
*     Date:     November 12, 2004                                       *;
*     Author:   SNG									*;
*     Purpose:  Take data from AJPS 2001 article and add variable for   *;
*               election - 1 if government coalition formed after an    *;
*               election, 0 if a government formed in the inter-election*;   
*               period.  Also add new pre-electoral coalition variable  *;
*               (in addition to their electoral pact variable) - 1 if   *;
*               an electoral coalition formed (prior to an election),   *;
*               0 otherwise.  I only consider electoral coalitions as   *;
*               forming prior to elections. Add investiture variable as *;
*               well - 1 if country uses investiture, 0 otherwise.      *;
*     Data Used:   formation03.dta                                      *;
*     Output File: data_setup.log                                       *;
*     Data Output: formation_new.dta                                    *;
*     Machine:     laptop (compaq)                                      *;
*     ****************************************************************  *;
*     ****************************************************************  *;


set matsize 150;
set mem 100m;
set more off;

use C:\datasets\formation03.dta;

*     ****************************************************************  *;
*       First create investiture variable. this term is needed to       *;
*       properly analyze the interaction term (between investiture      *;
*       and minority government).                                       *;
*     ****************************************************************  *;

generate invest=0;

replace invest=1 if country==11;
replace invest=1 if country==21;
replace invest=1 if country==32;
replace invest=1 if country==53;
replace invest=1 if country==72;

*     ****************************************************************  *;
*      Now create election variable. this term is needed to             *;
*      distinguish between government formation opportunities that      *;
*      occur after elections and those that occur in-between elections. *;
*     ****************************************************************  *;

generate election=0;

replace election=1 if country==11 & formopp==3;
replace election=1 if country==11 & formopp==5;
replace election=1 if country==11 & formopp==6;
replace election=1 if country==11 & formopp==8;
replace election=1 if country==11 & formopp==9;
replace election=1 if country==11 & formopp==10;
replace election=1 if country==11 & formopp==13;
replace election=1 if country==11 & formopp==14;
replace election=1 if country==11 & formopp==15;
replace election=1 if country==11 & formopp==17;
replace election=1 if country==11 & formopp==19;
replace election=1 if country==11 & formopp==20;

replace election=1 if country==12 & formopp==7;
replace election=1 if country==12 & formopp==10;
replace election=1 if country==12 & formopp==11;
replace election=1 if country==12 & formopp==14;
replace election=1 if country==12 & formopp==16;
replace election=1 if country==12 & formopp==20;

replace election=1 if country==13 & formopp==2;
replace election=1 if country==13 & formopp==3;
replace election=1 if country==13 & formopp==5;
replace election=1 if country==13 & formopp==6;
replace election=1 if country==13 & formopp==8;
replace election=1 if country==13 & formopp==10;
replace election=1 if country==13 & formopp==12;
replace election=1 if country==13 & formopp==13;
replace election=1 if country==13 & formopp==14;
replace election=1 if country==13 & formopp==15;
replace election=1 if country==13 & formopp==17;
replace election=1 if country==13 & formopp==18;
replace election=1 if country==13 & formopp==19;
replace election=1 if country==13 & formopp==21;
replace election=1 if country==13 & formopp==22;
replace election=1 if country==13 & formopp==24;

replace election=1 if country==15 & formopp==2;
replace election=1 if country==15 & formopp==3;
replace election=1 if country==15 & formopp==7;
replace election=1 if country==15 & formopp==8;
replace election=1 if country==15 & formopp==10;
replace election=1 if country==15 & formopp==12;
replace election=1 if country==15 & formopp==13;
replace election=1 if country==15 & formopp==14;
replace election=1 if country==15 & formopp==15;
replace election=1 if country==15 & formopp==17;
replace election=1 if country==15 & formopp==18;

replace election=1 if country==21 & formopp==1;
replace election=1 if country==21 & formopp==6;
replace election=1 if country==21 & formopp==10;
replace election=1 if country==21 & formopp==11;
replace election=1 if country==21 & formopp==13;
replace election=1 if country==21 & formopp==14;
replace election=1 if country==21 & formopp==16;
replace election=1 if country==21 & formopp==17;
replace election=1 if country==21 & formopp==19;
replace election=1 if country==21 & formopp==22;
replace election=1 if country==21 & formopp==23;
replace election=1 if country==21 & formopp==29;
replace election=1 if country==21 & formopp==30;

replace election=1 if country==22 & formopp==1;
replace election=1 if country==22 & formopp==3;
replace election=1 if country==22 & formopp==4;
replace election=1 if country==22 & formopp==6;
replace election=1 if country==22 & formopp==7;
replace election=1 if country==22 & formopp==10;
replace election=1 if country==22 & formopp==11;
replace election=1 if country==22 & formopp==12;
replace election=1 if country==22 & formopp==14;
replace election=1 if country==22 & formopp==15;
replace election=1 if country==22 & formopp==17;
replace election=1 if country==22 & formopp==18;

replace election=1 if country==23 & formopp==4;
replace election=1 if country==23 & formopp==9;
replace election=1 if country==23 & formopp==11;
replace election=1 if country==23 & formopp==12;
replace election=1 if country==23 & formopp==13;
replace election=1 if country==23 & formopp==14;

replace election=1 if country==32 & formopp==5;
replace election=1 if country==32 & formopp==11;
replace election=1 if country==32 & formopp==16;
replace election=1 if country==32 & formopp==20;
replace election=1 if country==32 & formopp==27;
replace election=1 if country==32 & formopp==32;
replace election=1 if country==32 & formopp==35;
replace election=1 if country==32 & formopp==41;
replace election=1 if country==32 & formopp==43;

replace election=1 if country==41 & formopp==1;
replace election=1 if country==41 & formopp==2;
replace election=1 if country==41 & formopp==8;
replace election=1 if country==41 & formopp==11;
replace election=1 if country==41 & formopp==13;
replace election=1 if country==41 & formopp==14;
replace election=1 if country==41 & formopp==17;
replace election=1 if country==41 & formopp==18;
replace election=1 if country==41 & formopp==20;
replace election=1 if country==41 & formopp==21;

replace election=1 if country==42 & formopp==1;
replace election=1 if country==42 & formopp==3;
replace election=1 if country==42 & formopp==4;
replace election=1 if country==42 & formopp==5;
replace election=1 if country==42 & formopp==8;
replace election=1 if country==42 & formopp==11;
replace election=1 if country==42 & formopp==15;
replace election=1 if country==42 & formopp==16;

replace election=1 if country==51 & formopp==12;

replace election=1 if country==53 & formopp==2;
replace election=1 if country==53 & formopp==6;
replace election=1 if country==53 & formopp==13;
replace election=1 if country==53 & formopp==14;
replace election=1 if country==53 & formopp==15;
replace election=1 if country==53 & formopp==16;

replace election=1 if country==62 & formopp==5;
replace election=1 if country==62 & formopp==7;
replace election=1 if country==62 & formopp==8;
replace election=1 if country==62 & formopp==9;
replace election=1 if country==62 & formopp==12;
replace election=1 if country==62 & formopp==14;

replace election=1 if country==72 & formopp==5;
replace election=1 if country==72 & formopp==8;
replace election=1 if country==72 & formopp==9;
replace election=1 if country==72 & formopp==12;
replace election=1 if country==72 & formopp==15;
replace election=1 if country==72 & formopp==17;
replace election=1 if country==72 & formopp==20;
replace election=1 if country==72 & formopp==22;

*     ****************************************************************  *;
*      Finally, create pre-electoral coalition variable. First need to  *;
*      turn the "govt" variable into a numeric variable, since can't    *;
*      work with it as a string variable.                               *;
*     ****************************************************************  *;

encode govt, gen(govtnum);

gen pec=0;

replace pec=1 if country==11 & formopp==3 & govtnum==1538;; *govt030405*;
replace pec=1 if country==11 & formopp==5 & govtnum==1409; *govt0205*;
replace pec=1 if country==11 & formopp==14 & govtnum==1538; *govt030405*;
replace pec=1 if country==11 & formopp==15 & govtnum==1538; *govt030405*;
replace pec=1 if country==11 & formopp==17 & govtnum==1538; *govt030405*;
replace pec=1 if country==11 & formopp==19 & govtnum==1538; *govt030405*;

replace pec=1 if country==12 & formopp==10 & govtnum==1539; *govt03040506*;
replace pec=1 if country==12 & formopp==11 & govtnum==1027; *govt02030405*;
replace pec=1 if country==12 & formopp==16 & govtnum==1794; *govt040506*;
replace pec=1 if country==12 & formopp==20 & govtnum==1794; *govt040506*;

replace pec=1 if country==13 & formopp==14 & govtnum==1794; *govt040506*;

replace pec=1 if country==15 & formopp==7 & govtnum==2; *govt0102*;
replace pec=1 if country==15 & formopp==8 & govtnum==2; *govt0102*;
replace pec=1 if country==15 & formopp==10 & govtnum==2; *govt0102*;

replace pec=1 if country==21 & formopp==17 & govtnum==1921; *govt0506*;
replace pec=1 if country==21 & formopp==19 & govtnum==1985; *govt0607*;
replace pec=1 if country==21 & formopp==23 & govtnum==2017; *govt0708*;
replace pec=1 if country==21 & formopp==29 & govtnum==2017; *govt0708*;
replace pec=1 if country==21 & formopp==30 & govtnum==1539; *govt03040506*;

replace pec=1 if country==22 & formopp==11 & govtnum==2; *govt0102*;
replace pec=1 if country==22 & formopp==12 & govtnum==2; *govt01028;
replace pec=1 if country==22 & formopp==18 & govtnum==1793; *govt0405*;

replace pec=1 if country==23 & formopp==11 & govtnum==1281; *govt0204*;

replace pec=1 if country==32 & formopp==5 & govtnum==2; *govt0102*;

replace pec=1 if country==41 & formopp==2 & govtnum==1281; *govt0305*;
replace pec=1 if country==41 & formopp==14 & govtnum==2; *govt0102*;
replace pec=1 if country==41 & formopp==17 & govtnum==2; *govt0102*;
replace pec=1 if country==41 & formopp==18 & govtnum==2; *govt0102*;
replace pec=1 if country==41 & formopp==20 & govtnum==1537; *govt0304*;
replace pec=1 if country==41 & formopp==21 & govtnum==1537; *govt0304*;

replace pec=1 if country==42 & formopp==1 & govtnum==513; *govt0103*;
replace pec=1 if country==42 & formopp==3 & govtnum==513; *govt0103*;
replace pec=1 if country==42 & formopp==4 & govtnum==513; *govt0103*;
replace pec=1 if country==42 & formopp==5 & govtnum==513; *govt0103*;
replace pec=1 if country==42 & formopp==8 & govtnum==513; *govt0103*;
replace pec=1 if country==42 & formopp==16 & govtnum==1281; *govt0204*;

replace pec=1 if country==53 & formopp==2 & govtnum==2; *govt0102*;
replace pec=1 if country==53 & formopp==13 & govtnum==2; *govt0102*;
replace pec=1 if country==53 & formopp==14 & govtnum==2; *govt0102*;
replace pec=1 if country==53 & formopp==15 & govtnum==1025; *govt0203*;

*     ****************************************************************  *;
*       Descriptive stats: how many electoral coalition pacts ('pro')   *;
*       according to Martin and Stevenson, full sample and              *;
*       post-election only - how many PECs according to my data         *;
*     ****************************************************************  *;

sum pro if pro==1;

sum pro if pro==1 & election==1;

sum pec if pec==1 & election==1;

save "C:\datasets\formation_new.dta", replace;


log close;
